#
# spec file for package python-autopep8
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

Name:           python-autopep8
Version:        2.0.4
Release:        3.3
Summary:        Automatic generated to pep8 checked code
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/hhatto/autopep8
Source:         https://files.pythonhosted.org/packages/source/a/autopep8/autopep8-%{version}.tar.gz
Patch1:         https://github.com/hhatto/autopep8/commit/6ebcb3cfadd9b8764405e1cab24f4412f05b36bb.patch#/python312-skip-tests.patch
BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pycodestyle >= 2.8}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tomli if %python-base < 3.11}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
Requires:       python-pycodestyle >= 2.10.0
%if %{python_version_nodots} < 311
Requires:       python-tomli
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Autopep8 is automatic generated to pep8 checked code.
This is old style tool, wrapped pep8 via subprocess module.

%prep
%autosetup -p1 -n autopep8-%{version}
sed -i '1s/^#!.*//' autopep8.py # Remove she-bang line

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/autopep8

%check
export LANG="en_US.UTF-8"
%pytest -k 'not test_e701_with_escaped_newline_and_spaces'

%pre
# Since /usr/bin/autopep8 became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternativies-ified package:
[ -h %{_bindir}/autopep8 ] || rm -f %{_bindir}/autopep8

%post
%python_install_alternative autopep8

%postun
%python_uninstall_alternative autopep8

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/autopep8
%pycache_only %{python_sitelib}/__pycache__/*
%{python_sitelib}/autopep8.py*
%{python_sitelib}/autopep8-%{version}.dist-info

%changelog
* Sun Feb  4 2024 Dirk Müller <dmueller@suse.com>
- add python312-skip-tests.patch to skip failing tests from py312
* Mon Nov  6 2023 Giacomo Comes <gcomes.obs@gmail.com>
- add sle15_python_module_pythons
* Sat Oct  7 2023 Martin Schreiner <martin.schreiner@suse.com>
- Update to 2.0.4:
  * Changes from 2.0.4:
    Paugier fix pycodestyle missing whitespace.
    Try to fix an AttributeError related to pycodestyle 2.11.0.
  * Changes from 2.0.3:
    Add pre-commit configurations.
    Version dependent operator whitespace function.
    Update MANIFEST.in.
- Remove pycodestyle211.patch, as it was merged upstream.
* Fri Aug 25 2023 Markéta Machová <mmachova@suse.com>
- Add pycodestyle211.patch to fix tests
* Mon Mar 13 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.2:
  * Ignore DeprecationWarnings to fix tests on py3.11
  * fix: infinite loop in autopep8.fix_code without w50 ignore
    option
- drop ignore-deprecation.patch (upstream)
* Wed Jan 25 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add ignore-deprecation.patch to make it compatible with python 3.11
  gh#hhatto/autopep8#665
* Sat Jan 21 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.0.1
  * require pycodestyle 2.10.0 and higher version by @hhatto in
    [#659]
  * fix: e265, e266 by @hhatto in #663
- Release 2.0.0
  * Fix E265 and E266 confusion and overlap by @PeterJCLaw in #650
  * Use tomli in place of unmaintained toml package by @mgorny in
    [#629]
  * fix: special case of auto value with flake8 config by @hhatto
    in #653
- Release 1.7.0
  * Require pycodestyle 2.9.1 and higher version ( Thanks
    @heavenshell)
  * Drop support Python2.7
* Thu Nov  4 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.6.0
  * Fix: Ignore Settings for W292 Do Not Work
  * Fix: Multiple #autopep8: off/on directives in one file do not work
  * Fix: --hang-closing option does not work for non-indented lines
  * Requires pycodestyle >= 2.8
* Mon May 31 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Tue May 11 2021 Dirk Müller <dmueller@suse.com>
- update to 1.5.7:
  * python 3.9
  * disallow 0 for indent-size option
  * exit code is 99 when error occured cli option parsing
  * exit code correctly on permission denied failure
* Mon Apr  5 2021 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 1.5.6:
  * Update pycodestyle 2.7.0
  * Update test_autopep8.py after continued_indentation fix
  * continued_indentation: Make the E128 check similar to pycodestyle
  * Restore the original pep8 copyright notice
  * change: use build and twine tools for pypi upload
- changes from version 1.5.5:
  * drop py35
  * change test python version
  * (origin/v1) add unit test that multilines w605
  * remove unnecessary function
  * change: not convert raw string for w605 fixed method
  * docs: fix simple typo, requred -> required
  * change: toml package not to import until it is needed (for #566)
* Sat Aug 15 2020 Arun Persaud <arun@gmx.de>
- update to version 1.5.4:
  * Merge pull request #565 from hhatto/fix-issue-564
  * ignore SyntaxWarning in Python3.8+ when calling built-in compile()
    method
  * fix pytest command
  * fix coverage and upload codecov
  * install depends
  * flake8 target only autopep8.py
  * Fix pycodestyle
  * Revert formatting changes outside scope of this feature
  * Move the on-off tests to under unit-tests
  * Correct line number weirdness
  * Add tests
  * Improved efficiency of search for enabled/disable
  * added basic on-off functionality to autopep8
  * Merge pull request #553 from hhatto/issue-551
  * fix: ignoring w292 with in-place option
* Tue Jun  9 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.5.3:
  * requirement pycodestyle version 2.6.0+ ( #548 )
  * Expected pyproject.toml configuration syntax incompatible with TOML format ( #528 , #546 )
  * Fix incompatible exit code with --jobs=0 and --exit-code ( #543 , #545 )
  * Fix hangup E122 fixed method with backslash ( #540 , #541 )
* Fri Apr 24 2020 Arun Persaud <arun@gmx.de>
- update to version 1.5.2:
  * add test for verbose log
  * remove unnecessary format's argument
  * add unit test
  * fix incorrect E702 fixes with --select=E702 option
  * refactoring
  * enable exclude option when specify directly file args
  * add unit test: exclude option when specify directly file args
  * support parallel jobs for --diff option (#480)
  * add test for diff option parallel jobs
  * add python 3.8 to files
  * add unit test: --ignore=E503,E504 case
  * fix degrade to case of --select=W --ignore=W503
  * add test for W503,504 more complex case
- changes from version 1.5.1:
  * remove skip mark in test
  * refactoring
  * add unit test for w503 and w504 confliction case
  * change: both W503 and W504 are specified, priority is given to
    W503 (for #518)
  * fix E402 with __all__ (for #529)
  * Fix a bug causing both W503 and W504 to be ignored
  * return diff exit code when reading from stdin too
* Wed Jan 22 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.5
  * Support Python3.8
  * Support pyproject.toml with [tool.autopep8] section.
  * fix few bugs
* Sun Apr 21 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 1.4.4:
  * add github issue template
  * Clarify global config file documentation
  * fix e117
  * add py37 in tox envlist
  * fix import statement moved above the module doc by E402
  * Don't allow setting --ignore to enable conflicting fixes
  * Fix issue with W504 that causes a syntax error if there are
    comment
  * fix import moved above a future import
  * fix invalid exit code (for #455)
  * add unit test for exit code
  * fix to pointed out by pylint
  * noqa
  * check pycodestyle to test/test_autopep8.py
  * better match the signature of io.open
  * Fix invalid escape sequences in tests
  * Don't write the file unless there are changes
* Thu Nov 22 2018 Arun Persaud <arun@gmx.de>
- update to version 1.4.3:
  * w605 fixes for identical tokens
  * fix e402 fixed method when import some modules (for #447)
  * use _is_binary_operator
  * (origin/fix-w503-more-corner-cases) fix w503 with comment into
    pointed out line (for #446)
* Tue Oct 30 2018 Arun Persaud <arun@gmx.de>
- update to version 1.4.2:
  * strict autopep8
  * add test for w503 fixed method with empty line
  * fix IndexError in w503 fixed method
  * fix w504 with any other tokenize.OP
* Wed Oct 17 2018 Arun Persaud <arun@gmx.de>
- specfile:
  * update requirement of pycodestyle to >= 2.4
- update to version 1.4.1:
  * update description for --exit-code option
  * add unit test for --exit-code option
  * fix fail test
  * use --exit-code option value
  * add --exit-code option
  * format .rst
  * update readme
  * fallback, use .pep8 config
  * update requirement, pycodestyle 2.4.0 and higher version
  * refactoring
  * not change import statement to top of file when duplicate import
  * pycodestyle & autopep8
  * enable reading the settings from '.flake8' file
  * change default config path
  * change: return exit-code 1 when exists diff output
  * work around exception for #403
  * fix w503 with into comments (for #411)
  * handling exception with case of line comment
  * remove debug print
  * unit test for w503 and w504 fixed methods
  * implementation W504 fixed method.
  * W50x are set to DEFAULT_IGNORE
  * update test suite data for e72x test
  * add test for get_module_imports_on_top_of_file
  * improve e402 fixed method
  * update test suite output
  * update method list
  * add E402 fixed method and test
* Mon Sep  3 2018 Tomáš Chvátal <tchvatal@suse.com>
- Install license
- Delete old archive
* Sat Sep  1 2018 arun@gmx.de
- update to version 1.4:
  * py37
  * W690 add DEFAULT_IGNORE. (because Python3 is mainstream now)
  * strict pep8
  * update readme
  * fix E702 is not running in case of README.rst example
  * add unit test for e128 with -aaa option
  * fix exception in fix_w503, when do not pointing out W503
  * fix E305, when E303 and E305 are detected on the subsequent line
  * env: PEP8_VERSION=pypi,github
  * Travis CI: Add Python 3.7 to the testing
  * update acid test output data
  * seperate to e113 and e116 fixed method
  * Update links to PyPI in README.rst
  * add W605 fixed method
  * add unit test for w605 fixed method
  * Make test_e225_with_indentation_fix() actually use the fixer for
    E225
  * Add fixer for E252 "Missing whitespace around parameter equals"
  * ix: case that W503 in a continuous 5 or more lines
  * add test case for W503 in a continuous 5 or more lines
  * fix e731 with case of default argument
  * add test for e731 with default arguments
  * fix broken coverage script
  * Handle ValueError from check_syntax
* Sun Apr  1 2018 arun@gmx.de
- update to version 1.3.5:
  * add pypi version badge
  * refactoring (strict pylint)
  * fix e713 and e714 chain cases
  * add test for e713 and e714 chain cases
  * avoid e265
  * add test for #389
  * fix e265 when starts non-alphanumeric symbols (#389)
  * Drop support for EOL Python 3.3
  * Remove redundant Python 2.6 code
  * Rewrite unnecessary list comprehension as dict comprehension
  * Rewrite unnecessary dict call as literal
  * Rewrite unnecessary list literal as set literal
  * Rewrite unnecessary generator as set comprehension
  * Rewrite unnecessary generator as set comprehension
  * Use automatic formatters (py2.7+)
  * Remove redundant Python 2.6 code
  * change: not affeted FF(FromFeed) in Reindenter
  * add unit test for #322
  * read flake8 config
* Sun Feb  4 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 1.3.4:
  * support in some more cases in E712
  * add test for e712 with dict value
  * drop support Python2.6
  * strict pylint
  * add to E133 fixed method and available hang-closing option
  * fix unit test
  * add E226 in default ignore code
  * change: use compile() with dont_inherit=True
  * add test, invalid config key for autopep8
  * print enable config section and key-value in verbose mode
  * add test for w602 valid and invalid 2to3 fixed case, skip now
* Thu Oct 12 2017 arun@gmx.de
- update to version 1.3.3:
  * add verbose print for 2to3 fixer (for #325)
  * fix test suite output
  * for #338 (easy solution...)
  * Fix a bug in E305
  * care of corner cases for E713 (maybe, not perfect)
  * ignore 'not in' case for E713
  * add test for e713 regression (for #276)
  * strict pep8
  * improve w503 fixed method
  * more test case for w503
  * consider that w503 with comment (#323)
  * add test that w503 with comment
  * Avoid a crash when shortening comments
* Fri Aug  4 2017 jmatejek@suse.com
- convert to singlespec (this incidentally fixes bsc#1047622 which
  affected the now dropped python3-autopep8)
- update requirement name from pep8 to pycodestyle
- update to 1.3.2
  * upstream provides no changelog
* Tue Apr 21 2015 benoit.monin@gmx.fr
- update to 1.1.1: no upstream changelog
- add -q to test to avoid spamming the build log
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Thu Jul 10 2014 toddrme2178@gmail.com
- Update to 1.0.3
  + Upstream provides no changelog
* Fri May  9 2014 toddrme2178@gmail.com
- Update to 1.0.2:
  + Upstream provides no changelog
- Update to 1.0.1
- Update to 1.0.0
- Update to 0.9.7
- Update to 0.9.6
- Fix UnicodeDecodeError in unittests
* Fri Nov 15 2013 speilicke@suse.com
- Only ghost /etc/alternatives on 12.3 or newer
* Tue Nov  5 2013 speilicke@suse.com
- Update to version 0.9.5:
  + Upstream provides no changelog
- Run testsuite
- Implement update-alternatives
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Aug 21 2012 highwaystar.ru@gmail.com
- updated to version 0.7.3
- python3 package added
- spec improved
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 0.1.3
* Fri Jul  8 2011 saschpe@suse.de
- Initial version
